From 69c0e66994f01ce1bf2299fbce86aee7a1baa37b Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?J=C3=B6rg=20Krause?= <joerg.krause@embedded.rocks>
Date: Thu, 14 Apr 2016 23:42:31 +0200
Subject: [PATCH] Fix build without MTD support
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit

handlers/raw_handler and corelib/installer does not need flash.h.
corelib/stream_interface and core/swupdate should include flash.h only
conditionally.

This fixes build errors if HAVE_MTD is not set and libmtd is not available:

In file included from include/swupdate.h:25:0,
                 from handlers/raw_handler.c:33:
include/flash.h:26:24: fatal error: mtd/libmtd.h: No such file or directory

Signed-off-by: Jörg Krause <joerg.krause@embedded.rocks>
---
 core/swupdate.c            | 6 ++++++
 corelib/installer.c        | 1 -
 corelib/stream_interface.c | 2 ++
 handlers/raw_handler.c     | 2 --
 include/swupdate.h         | 1 -
 5 files changed, 8 insertions(+), 4 deletions(-)

diff --git a/core/swupdate.c b/core/swupdate.c
index 06bc3b5..5493aef 100644
--- a/core/swupdate.c
+++ b/core/swupdate.c
@@ -43,7 +43,9 @@
 #include "network_interface.h"
 #include "handler.h"
 #include "installer.h"
+#ifdef CONFIG_MTD
 #include "flash.h"
+#endif
 #include "lua_util.h"
 #include "mongoose_interface.h"
 #include "network_ipc.h"
@@ -62,12 +64,14 @@ static pthread_t network_daemon;
 /* Tree derived from the configuration file */
 static struct swupdate_cfg swcfg;
 
+#ifdef CONFIG_MTD
 /* Global MTD configuration */
 static struct flash_description flashdesc;
 
 struct flash_description *get_flash_info(void) {
 	return &flashdesc;
 }
+#endif
 
 static struct option long_options[] = {
 	{"verbose", no_argument, NULL, 'v'},
@@ -375,7 +379,9 @@ int main(int argc, char **argv)
 	int ac = 0;
 #endif
 
+#ifdef CONFIG_MTD
 	memset(&flashdesc, 0, sizeof(flashdesc));
+#endif
 	memset(main_options, 0, sizeof(main_options));
 	memset(image_url, 0, sizeof(image_url));
 	strcpy(main_options, "vhi:se:l:");
diff --git a/corelib/installer.c b/corelib/installer.c
index f1818f2..434cf78 100644
--- a/corelib/installer.c
+++ b/corelib/installer.c
@@ -38,7 +38,6 @@
 #include "util.h"
 #include "swupdate.h"
 #include "installer.h"
-#include "flash.h"
 #include "handler.h"
 #include "cpiohdr.h"
 #include "parsers.h"
diff --git a/corelib/stream_interface.c b/corelib/stream_interface.c
index 36c41ef..2660498 100644
--- a/corelib/stream_interface.c
+++ b/corelib/stream_interface.c
@@ -44,7 +44,9 @@
 #include "swupdate.h"
 #include "util.h"
 #include "handler.h"
+#ifdef CONFIG_MTD
 #include "flash.h"
+#endif
 #include "parsers.h"
 #include "network_ipc.h"
 #include "network_interface.h"
diff --git a/handlers/raw_handler.c b/handlers/raw_handler.c
index aa3510e..6059f88 100644
--- a/handlers/raw_handler.c
+++ b/handlers/raw_handler.c
@@ -29,10 +29,8 @@
 #include <errno.h>
 #include <string.h>
 
-#include <mtd/mtd-user.h>
 #include "swupdate.h"
 #include "handler.h"
-#include "flash.h"
 #include "util.h"
 
 void raw_handler(void);
diff --git a/include/swupdate.h b/include/swupdate.h
index e8af798..40c0f48 100644
--- a/include/swupdate.h
+++ b/include/swupdate.h
@@ -22,7 +22,6 @@
 
 #include <sys/types.h>
 #include "bsdqueue.h"
-#include "flash.h"
 #include "globals.h"
 
 typedef enum {
